==> phpgroupware-jp-0.9.16.003-pre1.tar.bz2: phpgroupware/admin/help/EN/session.php <==
<?php
  /**************************************************************************\
  * phpGroupWare - User manual                                               *
  * http://www.phpgroupware.org                                              *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

	/* $Id: session.php,v 1.4 2003/06/16 21:41:57 kazuyan Exp $ */
	
	$phpgw_flags = Array(
		'currentapp'	=> 'manual',
		'admin_header'	=> True,
		'enable_utilities_class'	=> True
	);
	$phpgw_info['flags'] = $phpgw_flags;
	include('../../../header.inc.php');
	$appname = 'admin';
?>
<img src="<?php echo $phpgw->common->image($appname,'navbar.gif'); ?>" border=0> 
<font face="<?php echo $phpgw_info['theme']['font']; ?>" size="2">
<p>
This function is usually only available to the systems administrator of the system.
Administration of all applications, user and group accounts, session logging and control.
<ul>
<li><b>Session management:</b>
<p><i>View sessions:</i>
<br>Current sessions, IP, Login Time, Idle Time, and gives option to kill session.
<p><i>View Access Log:</i>
<br>LoginId, IP, Login Time, Logout Time, Total time spent.
</ul>
<?php $phpgw->common->phpgw_footer(); ?>

==> phpgroupware-jp-0.9.16.012-pre1.tar.bz2: phpgroupware/admin/help/EN/session.php <==
<?php
  /**************************************************************************\
  * phpGroupWare - User manual                                               *
  * http://www.phpgroupware.org                                              *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

	/* $Id: session.php,v 1.5 2004/12/26 20:30:12 kazuyan Exp $ */
	
	$phpgw_flags = Array(
		'currentapp'	=> 'manual',
		'admin_header'	=> True,
		'enable_utilities_class'	=> True
	);
	$phpgw_info['flags'] = $phpgw_flags;
	include('../../../header.inc.php');
	$appname = 'admin';
?>
<img src="<?php echo $phpgw->common->image($appname,'navbar.gif'); ?>" border=0> 
<font face="<?php echo $phpgw_info['theme']['font']; ?>" size="2">
<p>
This function is usually only available to the systems administrator of the system.
Administration of all applications, user and group accounts, session logging and control.
<ul>
<li><b>Session management:</b>
<p><i>View sessions:</i>
<br />Current sessions, IP, Login Time, Idle Time, and gives option to kill session.
<p><i>View Access Log:</i>
<br />LoginId, IP, Login Time, Logout Time, Total time spent.
</ul>
<?php $phpgw->common->phpgw_footer(); ?>
